<?php
//
// File generated by Dolibarr installer 23.0.3 on [[file_generated]]
//
// Take a look at conf.php.example file for an example of conf.php file
// and explanations for all possibles parameters.
//
$dolibarr_main_url_root='[[softurl]]';
$dolibarr_main_document_root="[[softpath]]";
$dolibarr_main_url_root_alt='/custom';
$dolibarr_main_document_root_alt="[[softpath]]/custom";
$dolibarr_main_data_root="[[softdatadir]]";
$dolibarr_main_db_host='[[softdbhost]]';
$dolibarr_main_db_port='0';
$dolibarr_main_db_name='[[softdb]]';
$dolibarr_main_db_prefix='[[dbprefix]]';
$dolibarr_main_db_user='[[softdbuser]]';
$dolibarr_main_db_pass='[[softdbpass]]';
$dolibarr_main_db_type='mysqli';
$dolibarr_main_db_character_set='utf8';
$dolibarr_main_db_collation='utf8_general_ci';
// Authentication settings
$dolibarr_main_authentication='dolibarr';

//$dolibarr_main_demo='autologin,autopass';
// Security settings
$dolibarr_main_prod='0';
$dolibarr_main_force_https='0';
$dolibarr_main_restrict_os_commands='mariadb-dump, mariadb, mysqldump, mysql, pg_dump, pg_restore, clamdscan, clamdscan.exe';
$dolibarr_nocsrfcheck='0';
$dolibarr_main_instance_unique_id='[[instance_unique_id]]';
$dolibarr_mailing_limit_sendbyweb='0';
$dolibarr_mailing_limit_sendbycli='0';

//$dolibarr_lib_FPDF_PATH="";
//$dolibarr_lib_TCPDF_PATH="";
//$dolibarr_lib_FPDI_PATH="";
//$dolibarr_lib_TCPDI_PATH="";
//$dolibarr_lib_GEOIP_PATH="";
//$dolibarr_lib_NUSOAP_PATH="";
//$dolibarr_lib_ODTPHP_PATH="";
//$dolibarr_lib_ODTPHP_PATHTOPCLZIP="";
//$dolibarr_js_CKEDITOR='';
//$dolibarr_js_JQUERY='';
//$dolibarr_js_JQUERY_UI='';

//$dolibarr_font_DOL_DEFAULT_TTF='';
//$dolibarr_font_DOL_DEFAULT_TTF_BOLD='';
$dolibarr_main_distrib='standard';
